# CloseRentalFile


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**archive** | **bool** |  | [optional] [default to False]

## Example

```python
from core.v2.models.close_rental_file import CloseRentalFile

# TODO update the JSON string below
json = "{}"
# create an instance of CloseRentalFile from a JSON string
close_rental_file_instance = CloseRentalFile.from_json(json)
# print the JSON string representation of the object
print(CloseRentalFile.to_json())

# convert the object into a dict
close_rental_file_dict = close_rental_file_instance.to_dict()
# create an instance of CloseRentalFile from a dict
close_rental_file_from_dict = CloseRentalFile.from_dict(close_rental_file_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


